import pandas_datareader as web

def stock_returns(prices_df):
    cols = prices_df.columns
    for symbol in cols:
        prices_df[f"{symbol} returns"] = prices_df[symbol].pct_change()
    return prices_df






import requests 
from bs4 import BeautifulSoup
import pandas as pd


url = "https://www.cnbc.com/funds-and-etfs/"

res = requests.get(url).content

soup = BeautifulSoup(res, 'lxml')

# tables = soup.find_all('tbody',class_="BasicTable-tableBody")
td = soup.find_all("td", attrs={"class": "BasicTable-symbol"})

print(td)
# for table in tables:
#     tds = table.find_all('td',class_="BasicTable-symbol")
#     print(tds)





 


import sqlite3
import pandas as pd
from portVision.handler import datahandler

def write_prices(df):
    conn = sqlite3.connect("./portVision/data/universeDB")
    df.to_sql('adjclose',conn,if_exists="replace")
    conn.close()

def append_prices(df):
    conn = sqlite3.connect("./portVision/data/universeDB")
    existing = read_prices()
    for col in df.columns:
        existing[col]= df[col]
    existing.to_sql('adjclose',conn,if_exists="replace")
    conn.close()

def read_prices():
    conn = sqlite3.connect("./portVision/data/universeDB")
    sql = """ SELECT * from adjclose"""
    df = pd.read_sql(sql,conn,index_col="Date")
    return df

def build_universe(symbols_list):
    df = datahandler.get_close(symbols_list)
    write_prices(df)
    return df

def append_universe(symbols_list):
     df = datahandler.get_close(symbols_list)
     append_prices(df)
     return df


from portVision.portfolio.returns import stock_returns 

def build_portfolio(df):
    extended_db = stock_returns(df)
    port = extended_db[[col for col in extended_db.columns if "returns" in col]]
    return port


import setuptools 

setuptools.setup(
    name="portVision",
    version="0.5",
    description="Portfolio Analysis library for Cadence practice",
    homepage="#",
    author="Michael A. Ballard",
    author_email="ballard.michael@columbia.edu",
    packages=['portVision','portVision.handler','portVision.portfolio'],
    install_requires=["requests","pandas","numpy","pandas-datareader","matplotlib", "scipy","yfinance","beautifulsoup4"],
    zip_safe=False
    )
    

# python3 -m pip install -e.